@@ -46,6 +46,8 @@ class CreateDjangoModel:
             django_field, opts = self.django_field_precursor(field.type)
             if field.name == pk_key:
                 opts["primary_key"] = True
+                if django_field is models.ForeignKey:
+                    django_field = models.OneToOneField
 
             fields[field.name] = django_field(**opts)
         return fields
